@@ -4,7 +4,7 @@ from dagster_airbyte.utils import generate_materializations
 
 from dagster import AssetKey, Out, Output
 from dagster import _check as check
-from dagster.core.asset_defs import AssetsDefinition, multi_asset
+from dagster.core.definitions import AssetsDefinition, multi_asset
 from dagster.utils.backcompat import experimental
 
 
